@@ -46,7 +46,18 @@ class CriterionParser:
         :return: None
         """
         if self.url_type == 'movie':
-            self.__gather_movie_list_info([['', self.url]])
+            alt_url = self.guess_collection_url(self.url)
+            response = requests.get(alt_url)
+            if response.status_code == 200:
+                soup = BeautifulSoup(response.content, 'html5lib')
+                series_name, series = CriterionParser.get_collection_info(soup)
+                if len(series) > 0:
+                    self.__gather_movie_list_info([series[0]])
+                else:
+                    self.__gather_movie_list_info([['', self.url]])
+            else:
+                self.__gather_movie_list_info([['', self.url]])
+
         elif self.url_type == 'collection':
             self.series_name, self.extracted_episode_info = CriterionParser.get_collection_info(self.soup)
             self.__gather_movie_list_info(self.extracted_episode_info)
@@ -79,6 +90,9 @@ class CriterionParser:
                     continue
             movie_parser = CriterionMovieParse.MovieParse(url, time)
             self.all_movie_parsed_data.append(movie_parser.get_parsed_info())
+        # a collection of one is not a (named) collection
+        if len(self.all_movie_parsed_data) == 1 and self.url_type == "collection":
+            self.series_name = ""
 
     def __explore_possible_collections(self, movies_list):
         """
